==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GeographicPolylineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleShapeEventArgsDescriptionMetadata } from "./StyleShapeEventArgsDescriptionMetadata";
import { GeographicShapeSeriesBaseDescriptionMetadata } from "./GeographicShapeSeriesBaseDescriptionMetadata";
import { GeographicPolylineSeriesDescription } from "./GeographicPolylineSeriesDescription";
/**
 * @hidden
 */
export let GeographicPolylineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicPolylineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicPolylineSeriesDescriptionMetadata.a == null) {
                GeographicPolylineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicPolylineSeriesDescriptionMetadata.c(GeographicPolylineSeriesDescriptionMetadata.a);
            }
            if (a.j(GeographicPolylineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(GeographicPolylineSeriesDescriptionMetadata.a);
            StyleShapeEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicShapeSeriesBaseDescriptionMetadata.c(a);
            a.item("ShapeStyleSelectorRef", "(w:ShapeStyleSelector,wf:ShapeStyleSelector)DataRef::object");
            a.item("ShapeFill", "(w:ShapeStyle.Fill,wf:ShapeFill)String");
            a.item("ShapeStroke", "(w:ShapeStyle.Stroke,wf:ShapeStroke)String");
            a.item("ShapeStrokeThickness", "(w:ShapeStyle.StrokeThickness,wf:ShapeStrokeThickness)Number:double");
            a.item("ShapeOpacity", "(w:ShapeStyle.Opacity,wf:ShapeOpacity)Number:double");
            a.item("StyleShapeRef", "EventRef::styleShape");
        }
        static d(a) {
            GeographicPolylineSeriesDescriptionMetadata.b(a);
            a.aa("GeographicPolylineSeries", () => new GeographicPolylineSeriesDescription());
            a.z("GeographicPolylineSeries", GeographicPolylineSeriesDescriptionMetadata.a);
        }
    }
    GeographicPolylineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicPolylineSeriesDescriptionMetadata, 'GeographicPolylineSeriesDescriptionMetadata');
    GeographicPolylineSeriesDescriptionMetadata.a = null;
    return GeographicPolylineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GeographicPolylineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleShapeEventArgsDescriptionMetadata } from "./StyleShapeEventArgsDescriptionMetadata";
import { GeographicShapeSeriesBaseDescriptionMetadata } from "./GeographicShapeSeriesBaseDescriptionMetadata";
import { GeographicPolylineSeriesDescription } from "./GeographicPolylineSeriesDescription";
/**
 * @hidden
 */
export let GeographicPolylineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicPolylineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicPolylineSeriesDescriptionMetadata.a == null) {
                GeographicPolylineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicPolylineSeriesDescriptionMetadata.c(GeographicPolylineSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicPolylineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(GeographicPolylineSeriesDescriptionMetadata.a);
            StyleShapeEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicShapeSeriesBaseDescriptionMetadata.c(a);
            a.item("ShapeStyleSelectorRef", "(w:ShapeStyleSelector,wf:ShapeStyleSelector)DataRef::object");
            a.item("ShapeFill", "(w:ShapeStyle.Fill,wf:ShapeFill)String");
            a.item("ShapeStroke", "(w:ShapeStyle.Stroke,wf:ShapeStroke)String");
            a.item("ShapeStrokeThickness", "(w:ShapeStyle.StrokeThickness,wf:ShapeStrokeThickness)Number:double");
            a.item("ShapeOpacity", "(w:ShapeStyle.Opacity,wf:ShapeOpacity)Number:double");
            a.item("StyleShapeRef", "EventRef::styleShape");
        }
        static d(a) {
            GeographicPolylineSeriesDescriptionMetadata.b(a);
            a.ac("GeographicPolylineSeries", () => new GeographicPolylineSeriesDescription());
            a.ab("GeographicPolylineSeries", GeographicPolylineSeriesDescriptionMetadata.a);
        }
    }
    GeographicPolylineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicPolylineSeriesDescriptionMetadata, 'GeographicPolylineSeriesDescriptionMetadata');
    GeographicPolylineSeriesDescriptionMetadata.a = null;
    return GeographicPolylineSeriesDescriptionMetadata;
})();
